@@ -11,4 +11,7 @@ from pythonml.forecasting import arima_ordertuner
 from pythonml.plotter import testplot, fittingplot, plot_forecast
 from pythonml.plotter import variable_plotter, historyplot
 
-__version__ = "1.00"
\ No newline at end of file
+from pythonml.nlp import connect_twitter, get_hashtag_tweets, get_user_tweets
+from pythonml.nlp import tweet_to_dataframe, text_preprocessing
+
+__version__ = "1.01"
\ No newline at end of file
